AppMessage class

Constructors

AppMessage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

treyAgain → const String
trgyAgain → const String
try1Again → const String
tryA3gain → const String
tryAcgain → const String
tryAgain → const String
tryAngain → const String
trytAgain → const String
unAubthohrizedText → const String
unAunthorizedText → const String
unAutghorizedText → const String
unAuthgorizedText → const String
unAuthhorizedText → const String
unAuthohrizedText → const String
unAuthorgizedText → const String
unAuthorizedText → const String